Tips
=====

How to find corresponding python function for a C API
-----------------------------------------------------

Pls search the whole project or specific files for that C API. (Note, bindings
may also live in the macros in header files)
